@@ -275,7 +275,7 @@ def units2DF(colorGrayDF,includeGray = True, ncR=0.01, vdR = .01, adR =.01,ndR =
         com_nG1 = colorGrayDF.grayNodes.to_list()[i]
         com_eG1 = colorGrayDF.grayEdges.to_list()[i]
 
-        com_nC1b = [x[0][:-4] for x in com_nC1] # get the color node list without degree
+        com_nC1b = [re.sub(r'[2][a-zA-Z]{3}',"",x[0][:-4]) for x in com_nC1] # get the color node list without degree  in case 'thai2nnnfood2nnn' compound noun make sure convert to  'thaifood '
 
         if includeGray:
             commu1_nodes = {*com_nC1,*com_nG1}  # combine gray and color node 
