@@ -262,8 +262,11 @@ def text2edges(text,verbose = False, verbose_text= False,include_otherEdge = Fal
   #print(len(text4a))
   text4 = " ".join(text4a)
   #print(len(text4.split()))
-  text4 = text4.replace('-','') # -bedroom in case - still there
-
+  text4 = text4.replace('-',' ') # -bedroom in case - still there
+  
+  text4 = re.sub(' +', ' ', text4).strip()
+  #text4 = ',,, device I '
+  # 0 ,1 ,2 ,3 dvice 4 i  this is token i for ',,, device I' token i is 5 but text split length is 3
 
   all_new_comps1 = [x.lower() for x in all_new_comps]  # Tripadvisor entity will become tripadvisornnn after text2 lemma_en 
   all_new_comps1 = all_new_comps1 + all_new_comps +['be'] +ba_verbs
@@ -696,6 +699,9 @@ def target2edges(text,verbose = False, verbose_text= False,include_otherEdge = F
   text4 = " ".join(text4a)
   #print(len(text4.split()))
   text4 = text4.replace('-','') # -bedroom in case - still there
+  text4 = re.sub(' +', ' ', text4).strip()
+  #text4 = ',,, device I '
+  # 0 ,1 ,2 ,3 dvice 4 i  this is token i for ',,, device I' token i is 5 but text split length is 3
 
 
   all_new_comps1 = [x.lower() for x in all_new_comps]  # Tripadvisor entity will become tripadvisornnn after text2 lemma_en 
